@@ -2,7 +2,7 @@ from palp.middleware.middleware_spider_recycle import SpiderRecycleMiddleware
 from palp.middleware.middleware_request_recycle import RequestRecycleMiddleware
 from palp.middleware.middleware_request_check import RequestCheckMiddleware
 from palp.middleware.middleware_request_record import RequestRecordMiddleware
-from palp.middleware.middleware_cycle_spider_record import CycleSpiderRecordRequestMiddleware
+from palp.middleware.middleware_cycle_spider_record import CycleSpiderRecordMiddleware
 from palp.middleware.middleware_spider import SpiderMiddleware
 from palp.middleware.middleware_request import RequestMiddleware
 from palp.middleware.middleware_request_filter import RedisSetFilter, RedisBloomFilter, RedisSetFilterMiddleware, \
